@@ -7,7 +7,13 @@ use Dancer ':syntax';
 use Dancer::Plugin;
 
 our $AUTHORITY = 'SUKRIA';
-our $VERSION   = '0.04';
+our $VERSION   = '0.05';
+
+my $content_types = {
+    json => 'application/json',
+    yml  => 'text/x-yaml',
+    xml  => 'application/xml',
+};
 
 register prepare_serializer_for_format => sub {
     my $conf        = plugin_setting;
@@ -36,6 +42,8 @@ register prepare_serializer_for_format => sub {
         }
 
         set serializer => $serializer;
+        my $ct = $content_types->{$format} || setting('content_type');
+        content_type $ct;
     };
 };
 
@@ -177,13 +185,13 @@ Dancer::Plugin::REST - A plugin for writing RESTful apps with Dancer
     };
 
     # curl http://mywebservice/user/42.json
-    { "id": 42, "name": "John Foo", email: "jhon.foo@example.com"}
+    { "id": 42, "name": "John Foo", email: "john.foo@example.com"}
 
     # curl http://mywebservice/user/42.yml
     --
     id: 42
     name: "John Foo"
-    email: "jhon.foo@example.com"
+    email: "john.foo@example.com"
 
 =head1 DESCRIPTION
 
@@ -193,14 +201,14 @@ This plugin helps you write a RESTful webservice with Dancer.
 
 =head2 prepare_serializer_for_format
 
-When this pragam is used a before filter is set by the plugin to automatically
+When this pragma is used, a before filter is set by the plugin to automatically
 change the serializer when a format is detected in the URI.
 
 That means that each route you define with a B<:format> token will trigger a
-serializer defintion, if the format is known.
+serializer definition, if the format is known.
 
-This lets you define all the REST action you like aas regular Dancer route
-handlers, without taking care of the outgoing data format.
+This lets you define all the REST actions you like as regular Dancer route
+handlers, without explicitly handling the outgoing data format.
 
 =head2 resource
 
